@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-03-02'; # DATE
+our $DATE = '2023-03-10'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.021'; # VERSION
+our $VERSION = '1.022'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -50,10 +50,11 @@ gen_csv_util(
 
         # we add this key to the stash
         $r->{seen} = {};
+        $r->{fields_idx} = [];
 
         # check arguments
         for my $field (@{ $r->{util_args}{fields} }) {
-            die [404, "Unknown field '$field'"] unless defined $r->{input_fields_idx}{$field};
+            push @{ $r->{fields_idx} }, App::CSVUtils::_find_field($r->{input_fields}, $field);
         }
     },
 
@@ -61,8 +62,8 @@ gen_csv_util(
         my $r = shift;
 
         my @vals;
-        for my $field (@{ $r->{util_args}{fields} }) {
-            my $fieldval = $r->{input_row}[ $r->{input_fields_idx}{$field} ] // '';
+        for my $field_idx (@{ $r->{fields_idx} }) {
+            my $fieldval = $r->{input_row}[ $field_idx ] // '';
             push @vals, $r->{util_args}{ignore_case} ? lc($fieldval) : $fieldval;
         }
         my $val = join("|", @vals);
@@ -98,7 +99,7 @@ App::CSVUtils::csv_uniq - Report or omit duplicated values in CSV
 
 =head1 VERSION
 
-This document describes version 1.021 of App::CSVUtils::csv_uniq (from Perl distribution App-CSVUtils), released on 2023-03-02.
+This document describes version 1.022 of App::CSVUtils::csv_uniq (from Perl distribution App-CSVUtils), released on 2023-03-10.
 
 =head1 FUNCTIONS
 
